@@ -1099,7 +1099,7 @@ class Animation:
                                          extra_args=extra_args,
                                          metadata=metadata)
             else:
-                alt_writer = next(writers, None)
+                alt_writer = next(iter(writers), None)
                 if alt_writer is None:
                     raise ValueError("Cannot save animation: no writers are "
                                      "available. Please install ffmpeg to "
